# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_talos.client as __client
    client = __client
    import pulumiverse_talos.cluster as __cluster
    cluster = __cluster
    import pulumiverse_talos.machine as __machine
    machine = __machine
else:
    client = _utilities.lazy_import('pulumiverse_talos.client')
    cluster = _utilities.lazy_import('pulumiverse_talos.cluster')
    machine = _utilities.lazy_import('pulumiverse_talos.machine')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "talos",
  "mod": "machine/bootstrap",
  "fqn": "pulumiverse_talos.machine",
  "classes": {
   "talos:machine/bootstrap:Bootstrap": "Bootstrap"
  }
 },
 {
  "pkg": "talos",
  "mod": "machine/configurationApply",
  "fqn": "pulumiverse_talos.machine",
  "classes": {
   "talos:machine/configurationApply:ConfigurationApply": "ConfigurationApply"
  }
 },
 {
  "pkg": "talos",
  "mod": "machine/secrets",
  "fqn": "pulumiverse_talos.machine",
  "classes": {
   "talos:machine/secrets:Secrets": "Secrets"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "talos",
  "token": "pulumi:providers:talos",
  "fqn": "pulumiverse_talos",
  "class": "Provider"
 }
]
"""
)
